@@ -217,7 +217,7 @@ def _export_columnize_data(obj: typing.Any, default_column_name: str) -> \
             raise SBDFError("obj does not have unique column names")
         columns = obj.to_dict("list")
         column_names = obj.columns.tolist()
-        column_types = {str(k): _ValueTypeId.infer_from_dtype(v, f"column '{str(k)}'") for (k, v) in obj.iteritems()}
+        column_types = {str(k): _ValueTypeId.infer_from_dtype(v, f"column '{str(k)}'") for (k, v) in obj.items()}
     elif isinstance(obj, pd.Series):
         # Handle series as columnar data
         series_name = default_column_name if obj.name is None else obj.name
@@ -1065,12 +1065,15 @@ class _ValueTypeId(enum.IntEnum):
             return _ValueTypeId.infer_from_dtype(series.astype(series.cat.categories.dtype), series_description)
         typeid = {
             "bool": _ValueTypeId.BOOL,
+            "boolean": _ValueTypeId.BOOL,
             "int32": _ValueTypeId.INT,
             "Int32": _ValueTypeId.INT,
             "int64": _ValueTypeId.LONG,
             "Int64": _ValueTypeId.LONG,
             "float32": _ValueTypeId.FLOAT,
+            "Float32": _ValueTypeId.FLOAT,
             "float64": _ValueTypeId.DOUBLE,
+            "Float64": _ValueTypeId.DOUBLE,
             "datetime64[ns]": _ValueTypeId.DATETIME,
             "timedelta64[ns]": _ValueTypeId.TIMESPAN,
             "string": _ValueTypeId.STRING,
@@ -1526,6 +1529,8 @@ if gpd is not None:
         elif all(isinstance(x, shapely.geometry.LineString) for x in geom_series) or \
                 all(isinstance(x, shapely.geometry.LinearRing) for x in geom_series):
             table_metadata["MapChart.GeometryType"] = "Line"
+        elif all(isinstance(x, shapely.geometry.MultiLineString) for x in geom_series):
+            table_metadata["MapChart.GeometryType"] = "PolyLine"
         elif all(isinstance(x, shapely.geometry.Polygon) for x in geom_series):
             table_metadata["MapChart.GeometryType"] = "Polygon"
         else:
